# ```lasertram```

Welcome to the repository for `lasertram`, a package for the time resolved analysis for processing laser ablation inductively coupled plasma mass spectrometry (LA-ICP-MS) data. It is used for back-end calculations in the dashboard [LaserTRAM-DB](https://github.com/jlubbersgeo/laserTRAM-DB).

## Documentation

please see the [Documentation](https://jlubbersgeo.github.io/lasertram/) for more!

## Installation
[![PyPI](https://img.shields.io/pypi/v/lasertram.svg?style=flat)](https://pypi.python.org/pypi/lasertram)
[![Compatible Python Versions](https://img.shields.io/pypi/pyversions/lasertram.svg?style=flat)](https://pypi.org/project/lasertram/)
```
pip install lasertram
```

## Contributing

If you have features you'd like to see please open an issue or consider contributing yourself! I'm always happy to have help.

**Maintainer** Jordan Lubbers (jlubbers _at_ usgs.gov)
